@@ -1,11 +1,11 @@
-from requests import get as r_get
-from requests import post as r_post
+from requests import get
+from requests import post
 
 from . import utils
 from .type import ClientType, Optional, Response, Union
 
 
-def request_login(username: str, password: str) -> Response:
+def login(username: str, password: str) -> Response:
     '''Send POST request to MyKU auth/login API.
 
     API: https://myapi.ku.th/auth/login
@@ -23,10 +23,10 @@ def request_login(username: str, password: str) -> Response:
         Response object from auth/login API.
     '''
 
-    return r_post(**utils.gen_login_request_params(username, password))
+    return post(**utils.gen_login_request_params(username, password))
 
 
-def request_logout(access_token: Optional[str] = '',
+def logout(access_token: Optional[str] = '',
                    login_response: Optional[Union[Response, dict]] = {},
                    client: Optional[ClientType] = None) -> Response:
     '''Send POST request to MyKU auth/logout API.
@@ -40,10 +40,10 @@ def request_logout(access_token: Optional[str] = '',
     Parameters
     ----------
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -60,7 +60,7 @@ def request_logout(access_token: Optional[str] = '',
 
     params = utils.gen_request_args_f(logout, **locals())
 
-    return r_get(**params)
+    return post(**params)
 
 
 def get_schedule(access_token: Optional[str] = '',
@@ -80,21 +80,21 @@ def get_schedule(access_token: Optional[str] = '',
     Parameters
     ----------
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     user_type : Optional[str]
-        'userType' attribute from login response, identical to :class:`pymyku.attribute.User.USER_TYPE`
+        'userType' attribute from login response, Represented by :class:`pymyku.attribute.User.USER_TYPE`
     campus_code : Optional[str]
-        'campusCode' attribute from login response, identical to :class:`pymyku.attribute.Student.CAMPUS_CODE`, e.g. 'B'
+        'campusCode' attribute from login response, Represented by :class:`pymyku.attribute.Student.CAMPUS_CODE`, e.g. 'B'
         , e.g. 'B'
     faculty_code : Optional[str]
-        'facultyCode' attribute from login response, identical to :class:`pymyku.attribute.Student.FACULTY_CODE`
+        'facultyCode' attribute from login response, Represented by :class:`pymyku.attribute.Student.FACULTY_CODE`
     major_code : Optional[str]
-        'majorCode' attribute from login response, identical to :class:`pymyku.attribute.Student.MAJOR_CODE`
+        'majorCode' attribute from login response, Represented by :class:`pymyku.attribute.Student.MAJOR_CODE`
     student_status_code : Optional[str]
-        'studentStatusCode' attribute from login response, identical to :class:`pymyku.attribute.Student.STUDENT_STATUS_CODE`
+        'studentStatusCode' attribute from login response, Represented by :class:`pymyku.attribute.Student.STUDENT_STATUS_CODE`
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -110,7 +110,7 @@ def get_schedule(access_token: Optional[str] = '',
     '''
     params = utils.gen_request_args_f(get_schedule, **locals())
 
-    return r_get(**params)
+    return get(**params)
 
 
 def get_group_course(access_token: Optional[str] = '',
@@ -129,22 +129,22 @@ def get_group_course(access_token: Optional[str] = '',
     Parameters
     ----------
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     std_id : Optional[str]
-        'stdId' attribute from login response, identical to :class:`pymyku.attribute.Student.STD_ID` 
+        'stdId' attribute from login response, Represented by :class:`pymyku.attribute.Student.STD_ID` 
         , e.g. '20xxxx'
     academic_year : Optional[str]
-        'academicYr' attribute from schedule response, identical to :class:`pymyku.attribute.Schedule.ACADEMIC_YEAR`
+        'academicYr' attribute from schedule response, Represented by :class:`pymyku.attribute.Schedule.ACADEMIC_YEAR`
         , e.g. '2565'
     semester : Optional[str]
-        'semester' attribute from schedule response, identical to :class:`pymyku.attribute.Schedule.SEMESTER`
+        'semester' attribute from schedule response, Represented by :class:`pymyku.attribute.Schedule.SEMESTER`
         , e.g. '0' for summer, '1' for first semester and '2' for second semester.
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     schedule_response : Optional[Union[Response, dict]]
         Schedule response from :meth:`get_schedule`, 
-        identical to :class:`pymyku.attribute.FetchedResponses.SCHEDULE_RESPONSE`
+        Represented by :class:`pymyku.attribute.FetchedResponses.SCHEDULE_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -161,7 +161,7 @@ def get_group_course(access_token: Optional[str] = '',
 
     params = utils.gen_request_args_f(get_group_course, **locals())
 
-    return r_get(**params)
+    return get(**params)
 
 
 def get_check_grades(access_token: Optional[str] = '',
@@ -178,13 +178,13 @@ def get_check_grades(access_token: Optional[str] = '',
     Parameters
     ----------
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     std_code : Optional[str]
-        'stdCode' attribute from login response, identical to :class:`pymyku.attribute.Student.STD_CODE`
+        'stdCode' attribute from login response, Represented by :class:`pymyku.attribute.Student.STD_CODE`
         , e.g. '64xxxxxxxx'
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -201,7 +201,7 @@ def get_check_grades(access_token: Optional[str] = '',
 
     params = utils.gen_request_args_f(get_check_grades, **locals())
 
-    return r_get(**params)
+    return get(**params)
 
 
 def get_gpax(access_token: Optional[str] = '',
@@ -217,13 +217,13 @@ def get_gpax(access_token: Optional[str] = '',
     Parameters
     ----------
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     std_id : Optional[str]
-        'stdId' attribute from login response, identical to :class:`pymyku.attribute.Student.STD_ID` 
+        'stdId' attribute from login response, Represented by :class:`pymyku.attribute.Student.STD_ID` 
         , e.g. '20xxxx'
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -240,7 +240,7 @@ def get_gpax(access_token: Optional[str] = '',
 
     params = utils.gen_request_args_f(get_gpax, **locals())
 
-    return r_get(**params)
+    return get(**params)
 
 
 def get_announce(access_token: Optional[str] = '',
@@ -259,22 +259,22 @@ def get_announce(access_token: Optional[str] = '',
     Parameters
     ----------
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     std_id : Optional[str]
-        'stdId' attribute from login response, identical to :class:`pymyku.attribute.Student.STD_ID` 
+        'stdId' attribute from login response, Represented by :class:`pymyku.attribute.Student.STD_ID` 
         , e.g. '20xxxx'
     academic_year : Optional[str]
-        'academicYr' attribute from schedule response, identical to :class:`pymyku.attribute.Schedule.ACADEMIC_YEAR`
+        'academicYr' attribute from schedule response, Represented by :class:`pymyku.attribute.Schedule.ACADEMIC_YEAR`
         , e.g. '2565'
     semester : Optional[str]
-        'semester' attribute from schedule response, identical to :class:`pymyku.attribute.Schedule.SEMESTER`
+        'semester' attribute from schedule response, Represented by :class:`pymyku.attribute.Schedule.SEMESTER`
         , e.g. '0' for summer, '1' for first semester and '2' for second semester.
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     schedule_response : Optional[Union[Response, dict]]
         Schedule response from :meth:`get_schedule`, 
-        identical to :class:`pymyku.attribute.FetchedResponses.SCHEDULE_RESPONSE`
+        Represented by :class:`pymyku.attribute.FetchedResponses.SCHEDULE_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -291,7 +291,7 @@ def get_announce(access_token: Optional[str] = '',
 
     params = utils.gen_request_args_f(get_announce, **locals())
 
-    return r_get(**params)
+    return get(**params)
 
 
 def search_enroll(access_token: Optional[str] = '',
@@ -310,22 +310,22 @@ def search_enroll(access_token: Optional[str] = '',
     Parameters
     ----------
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     std_id : Optional[str]
-        'stdId' attribute from login response, identical to :class:`pymyku.attribute.Student.STD_ID` 
+        'stdId' attribute from login response, Represented by :class:`pymyku.attribute.Student.STD_ID` 
         , e.g. '20xxxx'
     academic_year : Optional[str]
-        'academicYr' attribute from schedule response, identical to :class:`pymyku.attribute.Schedule.ACADEMIC_YEAR`
+        'academicYr' attribute from schedule response, Represented by :class:`pymyku.attribute.Schedule.ACADEMIC_YEAR`
         , e.g. '2565'
     semester : Optional[str]
-        'semester' attribute from schedule response, identical to :class:`pymyku.attribute.Schedule.SEMESTER`
+        'semester' attribute from schedule response, Represented by :class:`pymyku.attribute.Schedule.SEMESTER`
         , e.g. '0' for summer, '1' for first semester and '2' for second semester.
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     schedule_response : Optional[Union[Response, dict]]
         Schedule response from :meth:`get_schedule`, 
-        identical to :class:`pymyku.attribute.FetchedResponses.SCHEDULE_RESPONSE`
+        Represented by :class:`pymyku.attribute.FetchedResponses.SCHEDULE_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -342,7 +342,7 @@ def search_enroll(access_token: Optional[str] = '',
 
     params = utils.gen_request_args_f(search_enroll, **locals())
 
-    return r_post(**params)
+    return post(**params)
 
 
 def get_student_personal(access_token: Optional[str] = '',
@@ -358,13 +358,13 @@ def get_student_personal(access_token: Optional[str] = '',
     Parameters
     ----------
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     std_id : Optional[str]
-        'stdId' attribute from login response, identical to :class:`pymyku.attribute.Student.STD_ID` 
+        'stdId' attribute from login response, Represented by :class:`pymyku.attribute.Student.STD_ID` 
         , e.g. '20xxxx'
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -381,7 +381,7 @@ def get_student_personal(access_token: Optional[str] = '',
 
     params = utils.gen_request_args_f(get_student_personal, **locals())
 
-    return r_get(**params)
+    return get(**params)
 
 
 def get_student_education(access_token: Optional[str] = '',
@@ -397,13 +397,13 @@ def get_student_education(access_token: Optional[str] = '',
     Parameters
     ----------
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     std_id : Optional[str]
-        'stdId' attribute from login response, identical to :class:`pymyku.attribute.Student.STD_ID` 
+        'stdId' attribute from login response, Represented by :class:`pymyku.attribute.Student.STD_ID` 
         , e.g. '20xxxx'
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -419,7 +419,7 @@ def get_student_education(access_token: Optional[str] = '',
     '''
     params = utils.gen_request_args_f(get_student_education, **locals())
 
-    return r_get(**params)
+    return get(**params)
 
 
 def get_student_address(access_token: Optional[str] = '',
@@ -435,13 +435,13 @@ def get_student_address(access_token: Optional[str] = '',
     Parameters
     ----------
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     std_id : Optional[str]
-        'stdId' attribute from login response, identical to :class:`pymyku.attribute.Student.STD_ID` 
+        'stdId' attribute from login response, Represented by :class:`pymyku.attribute.Student.STD_ID` 
         , e.g. '20xxxx'
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -458,7 +458,7 @@ def get_student_address(access_token: Optional[str] = '',
 
     params = utils.gen_request_args_f(get_student_address, **locals())
 
-    return r_get(**params)
+    return get(**params)
 
 
 def search_subject(query: str,
@@ -474,12 +474,12 @@ def search_subject(query: str,
     Parameters
     ----------
     query : str
-        Subject id, e.g. '013' or '01355119'
+        Subject id or name to query. (At least 3 characters), e.g. '013', '01355119', 'eng' or 'english'
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -496,7 +496,7 @@ def search_subject(query: str,
 
     params = utils.gen_request_args_f(search_subject, **locals())
 
-    return r_get(**params)
+    return get(**params)
 
 
 def search_subject_open(query: str,
@@ -521,22 +521,23 @@ def search_subject_open(query: str,
     section : Optional[str]
         Section of the subject, e.g. '1'
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     campus_code : Optional[str]
-        'campusCode' attribute from login response, identical to :class:`pymyku.attribute.Student.CAMPUS_CODE`, e.g. 'B'
-        , e.g. 'B'
+        'campusCode' attribute from login response, Represented by :class:`pymyku.attribute.Student.CAMPUS_CODE`,
+        e.g. Campus code, 'B' for Bang Khen, 'C' for Sakolkorn, 'I' for affiliated institute, 
+        'K' for Kamphaeng Saen, 'P' for Suphanburi.
     academic_year : Optional[str]
-        'academicYr' attribute from schedule response, identical to :class:`pymyku.attribute.Schedule.ACADEMIC_YEAR`
+        'academicYr' attribute from schedule response, Represented by :class:`pymyku.attribute.Schedule.ACADEMIC_YEAR`
         , e.g. '2565'
     semester : Optional[str]
-        'semester' attribute from schedule response, identical to :class:`pymyku.attribute.Schedule.SEMESTER`
+        'semester' attribute from schedule response, Represented by :class:`pymyku.attribute.Schedule.SEMESTER`
         , e.g. '0' for summer, '1' for first semester and '2' for second semester.
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     schedule_response : Optional[Union[Response, dict]]
         Schedule response from :meth:`get_schedule`, 
-        identical to :class:`pymyku.attribute.FetchedResponses.SCHEDULE_RESPONSE`
+        Represented by :class:`pymyku.attribute.FetchedResponses.SCHEDULE_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -553,7 +554,7 @@ def search_subject_open(query: str,
 
     params = utils.gen_request_args_f(search_subject_open, **locals())
 
-    return r_get(**params)
+    return get(**params)
 
 
 def search_section_detail(section_id: str,
@@ -569,10 +570,10 @@ def search_section_detail(section_id: str,
     section_id : str
         Section id. e.g. '186426'
     access_token : Optional[str]
-        'accesstoken' from login response, identical to :class:`pymyku.attribute.Token.ACCESS_TOKEN`
+        'accesstoken' from login response, Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     login_response : Optional[Union[Response, dict]]
-        Login response from login request, can be obtained from :meth:`request_login`
-        identical to :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
+        Login response from login request, can be obtained from :meth:`login`
+        Represented by :class:`pymyku.attribute.FetchedResponses.LOGIN_RESPONSE`
     client : Optional[ClientType]
         Initialized :class:`pymyku.Client` object
 
@@ -589,4 +590,4 @@ def search_section_detail(section_id: str,
 
     params = utils.gen_request_args_f(search_section_detail, **locals())
 
-    return r_get(**params)
+    return get(**params)
