@@ -1,8 +1,8 @@
 from enum import Enum, EnumMeta
-from requests import Response
-from typing import Dict, List, Any, Union
+from typing import Any, Dict, List, Optional, Union
 
+from requests import Response
 
 class ClientType(object):
     '''Abstract class for client'''
-    pass
\ No newline at end of file
+    pass
