@@ -1,5 +1,7 @@
-from . import attribute, constant, url
-from .type import (Any, ClientType, Dict, Enum, EnumMeta, Optional, Response, Union)
+from . import constant, url
+from .attribute import FetchedResponses, Schedule, Student, Token, User
+from .type import (Any, ClientType, Dict, Enum, EnumMeta, Optional, Response,
+                   Union)
 
 
 def response_to_json(response: Union[Response, dict]) -> dict:
@@ -61,36 +63,36 @@ def extract(response: Union[Response, dict], attr: Enum) -> Any:
 
     response = response_to_json(response)
 
-    if isinstance(attr, attribute.User):
+    if isinstance(attr, User):
         return response.get("user", {})\
             .get(attr.value, None)
 
-    if isinstance(attr, attribute.Student):
+    if isinstance(attr, Student):
         return response.get("user", {})\
             .get("student", {})\
             .get(attr.value, None)
 
-    if isinstance(attr, attribute.Token):
+    if isinstance(attr, Token):
         return response.get(attr.value, None)
 
-    if isinstance(attr, attribute.Schedule):
+    if isinstance(attr, Schedule):
         result = response.get("results", [])
         if not result:
             return None
         return result[0].get(attr.value, None)
 
 
-def get_raise(dict_: dict, key: str, dict_name: Optional[str] = None) -> Any:
-    '''Raise VakueError if key is not found in dict_.
+def get_raise(dictionary: dict, key: str, dict_name: Optional[str] = None) -> Any:
+    '''Raise ValueError if key is not found in dictionary.
 
     Parameters
     ----------
-    dict_ : dict
-        _description_
+    dictionary : dict
+        The dictionary to search in.
     key : str
-        _description_
+        The key to search for.
     dict_name : Optional[str]
-        _description_, by default None
+        Name of the dictionary.
 
     Returns
     -------
@@ -100,10 +102,10 @@ def get_raise(dict_: dict, key: str, dict_name: Optional[str] = None) -> Any:
     Raises
     ------
     ValueError
-        If key is not found in dict_.
+        If key is not found in dictionary.
     '''
 
-    result = dict_.get(key)
+    result = dictionary.get(key)
     if result is None:
         raise ValueError(
             f'{key} is not found in {dict_name if dict_name else "dictionary"}')
@@ -121,7 +123,7 @@ def extract_user_data(login_response: Union[Response, dict]) -> dict:
     Returns
     -------
     dict
-        User data.
+        User data. Represented by :class:`pymyku.attribute.User`
         
     Raises
     ------
@@ -147,7 +149,7 @@ def extract_student_data(login_response: Union[Response, dict]) -> dict:
     Returns
     -------
     dict
-        Student data.
+        Student data. Represented by :class:`pymyku.attribute.Student`
         
     Raises
     ------
@@ -173,7 +175,7 @@ def extract_access_token(login_response: Union[Response, dict]) -> str:
     Returns
     -------
     str
-        Access token. Identical to pymyku.attribute.Token.ACCESS_TOKEN.
+        Access token. Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
         
     Raises
     ------
@@ -199,7 +201,7 @@ def extract_std_code(login_response: Union[Response, dict]) -> str:
     Returns
     -------
     str 
-        Student code.
+        Student code. Represented by :class:`pymyku.attribute.Student.STD_CODE`
     '''
 
     login_response = response_to_json(login_response)
@@ -212,7 +214,7 @@ def extract_std_code(login_response: Union[Response, dict]) -> str:
 
 
 def extract_std_id(login_response: Union[Response, dict]) -> str:
-    '''Extract student id from login response
+    '''Extract student id from login response.
 
     Parameters
     ----------
@@ -222,7 +224,7 @@ def extract_std_id(login_response: Union[Response, dict]) -> str:
     Returns
     -------
     str
-        Student id.
+        Student id. Represented by :class:`pymyku.attribute.Student.STD_ID`
     '''
 
     login_response = response_to_json(login_response)
@@ -237,7 +239,7 @@ def extract_std_id(login_response: Union[Response, dict]) -> str:
 def extract_schedule(schedule_response: Union[Response, dict],
                      as_dict: Optional[bool] = False,
                      full_result: Optional[bool] = False) -> Union[tuple, dict, list]:
-    '''Extract schedule (academic_year, semester) from schedule response
+    '''Extract academic_year and semester from schedule response.
 
     Parameters
     ----------
@@ -251,7 +253,7 @@ def extract_schedule(schedule_response: Union[Response, dict],
     Returns
     -------
     Union[tuple, dict, list]
-        Dictionary containing schedule data.
+        Academic year and semester. Represented by :class:`pymyku.attribute.Schedule.ACADEMIC_YEAR` and :class:`pymyku.attribute.Schedule.SEMESTER`
     '''
 
     schedule_response = response_to_json(schedule_response)
@@ -267,8 +269,6 @@ def extract_schedule(schedule_response: Union[Response, dict],
     if as_dict:
         return result
 
-    print(result)
-
     academic_year = get_raise(result, 'academicYr', 'schedule response')
 
     semester = get_raise(result, 'semester', 'schedule response')
@@ -284,8 +284,8 @@ def gen_request_headers(access_token: Optional[Union[str, Response, dict]] = '')
     Parameters
     ----------
     access_token : Optional[Union[str, Response, dict]]
-        Access token, if the parameter is type Response or dict, the access token will be extracted, by default '
-
+        If the parameter is type Response or dict, the access token will be extracted.
+        Represented by :class:`pymyku.attribute.Token.ACCESS_TOKEN`
     Returns
     -------
     dict
@@ -318,8 +318,7 @@ def gen_login_request_params(username: str, password: str) -> dict:
     Returns
     -------
     dict
-        Request parameters.
-
+        Parameters for login request.
     '''
 
     return {
@@ -393,9 +392,9 @@ def gen_request_args_f(function: callable,
 
     if kwargs.get('client'):
         client = kwargs['client']
-        kwargs['login_response'] = client.get(attribute.FetchedResponses.LOGIN_RESPONSE)
+        kwargs['login_response'] = client.get(FetchedResponses.LOGIN_RESPONSE)
         kwargs['schedule_response'] = client.get(
-            attribute.FetchedResponses.SCHEDULE_RESPONSE)
+            FetchedResponses.SCHEDULE_RESPONSE)
 
     if kwargs.get('login_response'):
         login_response = kwargs.get('login_response')
@@ -498,7 +497,7 @@ def gen_request_args_f(function: callable,
             __check_required_kwargs(kwargs, ['std_id', 'academic_year', 'semester'])
 
         return {
-            'url': url.ANNOUCE,
+            'url': url.ANNOUNCE,
             'headers': headers,
             'params': {
                 'stdId': kwargs.get('std_id'),
